"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.npmPackageWorkspacesAction = void 0;

var _path = require("path");

var _util = require("util");

var _toolLib = require("@kettil/tool-lib");

var _glob = require("glob");

var _multipleWorkspacesError = require("../../errors/multipleWorkspacesError");

var _packageLoad = require("./packageLoad");

const globPromise = (0, _util.promisify)(_glob.glob);

const npmPackageWorkspacesAction = async argv => {
  const workspaces = await (0, _packageLoad.npmPackageLoadAction)(argv, {
    key: 'workspaces'
  });

  if (!(0, _toolLib.isArray)(workspaces)) {
    return [];
  }

  const paths = await Promise.all(workspaces.filter(_toolLib.isString).map(workspace => globPromise(workspace, {
    cwd: argv.root,
    absolute: true
  })));
  const workspaceUniques = (0, _toolLib.uniqueArray)(paths.flat());
  const workspaceDuplicateNames = (0, _toolLib.uniqueArray)(workspaceUniques.map(workspace => (0, _path.basename)(workspace)).filter((name, index, names) => names.indexOf(name) !== index).sort());

  if (workspaceDuplicateNames.length > 0) {
    throw new _multipleWorkspacesError.MultipleWorkspacesError(`The Workspaces exist more than once: ${workspaceDuplicateNames.join(', ')}`);
  }

  argv.log.info(['Workspaces:', ...workspaceUniques.map(w => `▸ ${w}`), '']);
  return workspaceUniques;
};

exports.npmPackageWorkspacesAction = npmPackageWorkspacesAction;