"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.babelAction = void 0;

var _path = require("path");

var _actionConfigs = require("../../../configs/actionConfigs");

var _execLog = require("../../cmd/execLog");

var _execReturn = require("../../cmd/execReturn");

var _getBabelConfigPath = require("../../utils/getBabelConfigPath");

const babelAction = async ({
  root,
  cwd,
  log
}, {
  watch,
  skipInitialBuild,
  spawnKillHandler
}) => {
  const configPath = await (0, _getBabelConfigPath.getBabelConfigPath)([cwd, root]);
  const cmd = (0, _path.join)(root, _actionConfigs.babelCommand);
  const args = [];
  args.push('-d', 'build');
  args.push('--config-file', configPath);
  args.push('--extensions', _actionConfigs.babelExtensions);

  if (watch) {
    args.push('--watch');

    if (skipInitialBuild) {
      args.push('--skip-initial-build');
    }
  }

  args.push('src');
  log.info('Run babel');
  const execOptions = {
    cmd,
    args,
    cwd,
    log,
    spawnKillHandler
  };

  if (watch) {
    await (0, _execLog.execLog)(execOptions);
  } else {
    await (0, _execReturn.execReturn)(execOptions);
  }
};

exports.babelAction = babelAction;