"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.babelNodeAction = void 0;

var _path = require("path");

var _actionConfigs = require("../../../configs/actionConfigs");

var _execStdio = require("../../cmd/execStdio");

var _createSpawnKillHandler = require("../../utils/createSpawnKillHandler");

var _getBabelConfigPath = require("../../utils/getBabelConfigPath");

var _pinoPretty = require("./pinoPretty");

const babelNodeAction = async ({
  root,
  cwd,
  log
}, {
  scriptPath,
  watch,
  clearConsole,
  watchPaths = [],
  executePath = cwd,
  withPinoPretty,
  pinoIgnoreKeys
}) => {
  const spawnKillHandler = watch === true ? (0, _createSpawnKillHandler.createSpawnKillHandler)({
    registerStdin: true
  }) : undefined;
  const pipe = withPinoPretty === true ? (0, _pinoPretty.pinoPretty)({
    log,
    root,
    cwd: executePath,
    pinoIgnoreKeys
  }) : undefined;
  const configPath = await (0, _getBabelConfigPath.getBabelConfigPath)([cwd, root]);
  const envPrefix = {
    DOTENV_CONFIG_PATH: (0, _path.join)((0, _path.relative)(executePath, root), '.env')
  };
  const cmd = (0, _path.join)(root, watch ? _actionConfigs.babelCommandWatch : _actionConfigs.babelCommandNode);
  const args = [];
  args.push('--extensions', _actionConfigs.babelExtensions);
  args.push('--config-file', configPath);

  if (watch) {
    args.push(...watchPaths.flatMap(path => ['--watch', path]));

    if (clearConsole) {
      args.push('--clear-console');
    }
  }

  args.push(scriptPath);
  log.info(`Run babel-${watch ? 'watch' : 'node'}`);
  await (0, _execStdio.execStdio)({
    log,
    cmd,
    args,
    cwd: executePath,
    spawnKillHandler,
    envPrefix
  }, {
    pipe
  });
};

exports.babelNodeAction = babelNodeAction;