"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.coverageAction = void 0;

var _path = require("path");

var _istanbulLibCoverage = require("istanbul-lib-coverage");

var _istanbulLibReport = require("istanbul-lib-report");

var _istanbulReports = require("istanbul-reports");

var _existFiles = require("../../cmd/existFiles");

var _readFile = require("../../cmd/readFile");

var _writeFile = require("../../cmd/writeFile");

var _messageError = require("../../errors/messageError");

var _getCoverageErrorMessage = require("../../utils/getCoverageErrorMessage");

var _getCoverageFolder = require("../../utils/getCoverageFolder");

var _getCoverageWatermark = require("../../utils/getCoverageWatermark");

const coverageFileName = 'coverage-final.json';
const coverageSuccessKeys = new Set(['high', 'medium']);
const watermarkKeys = ['statements', 'functions', 'branches', 'lines'];

const coverageAction = async (argv, {
  projects,
  watermarks = {}
}) => {
  const coverageFiles = await (0, _existFiles.existFiles)(projects.map(project => (0, _path.join)((0, _getCoverageFolder.getCoverageFolder)(argv.root, [project]), coverageFileName)));
  const coveragePath = (0, _getCoverageFolder.getCoverageFolder)(argv.root, []);
  const coverageMap = (0, _istanbulLibCoverage.createCoverageMap)({});
  const coverages = await Promise.all(coverageFiles.map(file => (0, _readFile.readFile)(file, true)));
  coverages.forEach(coverageData => coverageMap.merge(coverageData));
  await (0, _writeFile.writeFile)((0, _path.join)(coveragePath, coverageFileName), JSON.stringify(coverageMap));
  const context = (0, _istanbulLibReport.createContext)({
    coverageMap,
    dir: coveragePath,
    defaultSummarizer: 'pkg',
    watermarks: Object.fromEntries(watermarkKeys.map(key => [key, (0, _getCoverageWatermark.getCoverageWatermark)(watermarks[key])]))
  });
  const reports = ['lcovonly', 'json-summary', 'text-summary'];

  if (!argv.ci) {
    reports.push('html');
  }

  reports.forEach(report => (0, _istanbulReports.create)(report, {}).execute(context));
  const coverageSummary = coverageMap.getCoverageSummary();
  const coverageErrors = watermarkKeys.filter(key => !coverageSuccessKeys.has(context.classForPercent(key, coverageSummary[key].pct)));

  if (coverageErrors.length > 0) {
    throw new _messageError.MessageError(coverageErrors.map(key => (0, _getCoverageErrorMessage.getCoverageErrorMessage)(key, watermarks, coverageSummary)).join('\n'));
  }
};

exports.coverageAction = coverageAction;