"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.logger = exports.log = void 0;

var _toolLib = require("@kettil/tool-lib");

var _chalk = _interopRequireDefault(require("chalk"));

var _spinner = require("./spinner");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const levels = {
  log: msg => msg,
  error: _chalk.default.red,
  info: _chalk.default.green,
  debug: _chalk.default.blue
};
const maxLevelLength = Object.keys(levels).reduce((p, c) => Math.max(p, c.length), 0);

const getMessageLevel = level => levels[level](level.toUpperCase().padEnd(maxLevelLength));

const write = (type, message) => {
  process[type].write(`${message.trimEnd()}\n`);
};

const logging = (level, type) => msg => {
  const resume = (0, _spinner.spinnerBreak)();
  const messages = (0, _toolLib.isArray)(msg) ? msg : msg.replace(/\n$/u, '').split('\n');
  messages.forEach(m => {
    write(type, `[${new Date().toISOString()}] ${level}: ${m}`);
  });
  resume();
};

const log = msg => {
  const indent = (0, _spinner.isSpinning)() ? '  ' : '';
  const resume = (0, _spinner.spinnerBreak)();
  const messages = (0, _toolLib.isArray)(msg) ? msg : msg.trimEnd().split('\n');
  write('stdout', messages.map(v => indent + v).join('\n'));
  resume();
};

exports.log = log;

const logger = ({
  verbose,
  vvv
}) => {
  const error = logging(getMessageLevel('error'), 'stderr');
  const info = logging(getMessageLevel('info'), 'stdout');
  const debug = logging(getMessageLevel('debug'), 'stdout');

  if (vvv) {
    return {
      log,
      error,
      info,
      debug
    };
  }

  if (verbose) {
    return {
      log,
      error,
      info,
      debug: _toolLib.dummy
    };
  }

  return {
    log,
    error: _toolLib.dummy,
    info: _toolLib.dummy,
    debug: _toolLib.dummy
  };
};

exports.logger = logger;