/// <reference types="node" />
import { ChildProcessWithoutNullStreams, ChildProcessByStdio } from 'child_process';
import { Readable, Writable } from 'stream';
import { Logger } from '../cli/logger';
import { SpawnKillHandler } from '../utils/createSpawnKillHandler';
declare type ExecOptions = {
    readonly cmd: string;
    readonly args: readonly string[];
    readonly spawnKillHandler?: SpawnKillHandler;
    readonly cwd: string;
    readonly envPrefix?: NodeJS.ProcessEnv;
    readonly envSuffix?: NodeJS.ProcessEnv;
    readonly log: Logger;
};
declare type U = undefined;
declare type N = null;
declare type R = Readable;
declare type W = Writable;
declare type Exec = {
    (options: ExecOptions): ChildProcessWithoutNullStreams;
    (options: ExecOptions, stdio: {
        stdin: W;
        stdout: R;
        stderr: R;
    }): ChildProcessByStdio<N, N, N>;
    (options: ExecOptions, stdio: {
        stdin: W;
        stdout: R;
        stderr: U;
    }): ChildProcessByStdio<N, N, R>;
    (options: ExecOptions, stdio: {
        stdin: W;
        stdout: U;
        stderr: R;
    }): ChildProcessByStdio<N, R, N>;
    (options: ExecOptions, stdio: {
        stdin: U;
        stdout: R;
        stderr: R;
    }): ChildProcessByStdio<W, N, N>;
    (options: ExecOptions, stdio: {
        stdin: W;
        stdout: U;
        stderr: U;
    }): ChildProcessByStdio<N, R, R>;
    (options: ExecOptions, stdio: {
        stdin: U;
        stdout: R;
        stderr: U;
    }): ChildProcessByStdio<W, N, R>;
    (options: ExecOptions, stdio: {
        stdin: U;
        stdout: U;
        stderr: R;
    }): ChildProcessByStdio<W, R, N>;
    (options: ExecOptions, stdio: {
        stdin: U;
        stdout: U;
        stderr: U;
    }): ChildProcessByStdio<W, R, R>;
    (options: ExecOptions, stdio: {
        stdin: U | W;
        stdout: R | U;
        stderr: R;
    }): ChildProcessByStdio<N | W, N | R, N>;
};
declare const getExecCommand: ({ cmd, args }: Pick<ExecOptions, 'args' | 'cmd'>) => string;
declare const exec: Exec;
export type { ExecOptions };
export { exec, getExecCommand };
