"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.execStdio = void 0;

var _process = require("../cli/process");

var _executableError = require("../errors/executableError");

var _exec = require("./exec");

const execStdio = (props, {
  registerStdin = false,
  pipe
} = {}) => new Promise((resolve, reject) => {
  const {
    stderr
  } = process;
  const stdout = pipe ? undefined : process.stdout;
  const stdin = registerStdin ? (0, _process.getStdin)() : undefined;

  if (stdin) {
    stdin.setEncoding('utf8');
    stdin.setRawMode(true);
    stdin.resume();
  }

  const stream = (0, _exec.exec)(props, {
    stdin,
    stdout,
    stderr
  });

  if (stream.stdout && pipe) {
    stream.stdout.pipe(pipe.stdin);
  }

  stream.once('close', code => {
    if (stdin) {
      stdin.setRawMode(false);
      stdin.pause();
    }

    if (typeof code === 'number' && code !== 0) {
      reject(new _executableError.ExecutableError('Error during execution', (0, _exec.getExecCommand)(props), code));
    } else {
      resolve();
    }
  });
});

exports.execStdio = execStdio;