"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.analyseTask = exports.analyseServices = void 0;

var _actionConfigs = require("../../configs/actionConfigs");

var _eslint = require("../actions/tools/eslint");

var _prettier = require("../actions/tools/prettier");

var _tsc = require("../actions/tools/tsc");

var _spinner = require("../cli/spinner");

var _hasDependency = require("../utils/hasDependency");

var _taskHook = require("../utils/taskHook");

const analyseServices = ['eslint', 'prettier', 'typescript'];
exports.analyseServices = analyseServices;

const isSelectedService = (value, service) => typeof value === 'undefined' || value === service;

const analyseTask = async (argv, {
  only,
  eslintFiles,
  prettierFiles
}) => {
  await (0, _taskHook.taskHook)(argv, {
    task: 'analyse',
    type: 'pre'
  });

  if (isSelectedService(only, 'prettier')) {
    const prettierOptions = {
      write: !argv.ci,
      extension: argv.ci ? _actionConfigs.prettierCiExtensions : undefined,
      files: prettierFiles
    };
    await (0, _spinner.spinnerAction)((0, _prettier.prettierAction)(argv, prettierOptions), 'Analyse: Prettier');
  }

  if (isSelectedService(only, 'eslint')) {
    const eslintOptions = {
      write: !argv.ci,
      files: eslintFiles
    };
    await (0, _spinner.spinnerAction)((0, _eslint.eslintAction)(argv, eslintOptions), 'Analyse: ESLint');
  }

  if (isSelectedService(only, 'typescript')) {
    const hasTypescript = await (0, _hasDependency.hasDependency)(argv, {
      dependency: 'typescript',
      dependencyType: 'devDependencies'
    });

    if (hasTypescript) {
      await (0, _spinner.spinnerAction)((0, _tsc.tscAction)(argv, {
        mode: 'type-check'
      }), 'Analyse: Typescript');
    }
  }

  await (0, _taskHook.taskHook)(argv, {
    task: 'analyse',
    type: 'post'
  });
};

exports.analyseTask = analyseTask;