"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.licenseTask = void 0;

var _path = require("path");

var _toolLib = require("@kettil/tool-lib");

var _chalk = require("chalk");

var _packageWorkspaces = require("../actions/npm/packageWorkspaces");

var _licensecheckAction = require("../actions/tools/licensecheckAction");

var _config = require("../cli/config");

var _spinner = require("../cli/spinner");

var _table = require("../cli/table");

var _exit = require("../cmd/exit");

var _licenseDisabledError = require("../errors/licenseDisabledError");

var _licenseIncompatibleError = require("../errors/licenseIncompatibleError");

var _taskHook = require("../utils/taskHook");

var _getLicenseConfigs = require("./license/getLicenseConfigs");

const notice = `the license check(s) is only a suggestion and is ${(0, _chalk.underline)('not')} legal advice`;

const licenseTask = async argv => {
  const workspacePaths = await (0, _packageWorkspaces.npmPackageWorkspacesAction)(argv);
  const config = await (0, _config.getConfig)(argv.root, 'license');
  const licenseConfig = (0, _getLicenseConfigs.getLicenseConfigs)((0, _toolLib.isObject)(config) ? config : {});
  await (0, _taskHook.taskHook)(argv, {
    task: 'license',
    type: 'pre'
  });

  try {
    await [argv.root, ...workspacePaths].reduce((promise, path) => promise.then(() => {
      const subTitle = path === argv.root ? `(${notice})` : `[${(0, _path.basename)(path)}]`;
      return (0, _spinner.spinnerAction)((0, _licensecheckAction.licensecheckAction)(argv, {
        path,
        licenseConfig
      }), `License verification ${subTitle}`);
    }), Promise.resolve());
  } catch (error) {
    if (error instanceof _licenseDisabledError.LicenseDisabledError) {
      return;
    }

    if (error instanceof _licenseIncompatibleError.LicenseIncompatibleError) {
      argv.log.log(' ');
      argv.log.log((0, _table.table)(error.list));
      argv.log.log(' ');
      (0, _exit.exit)();
    }

    throw error;
  }

  await (0, _taskHook.taskHook)(argv, {
    task: 'license',
    type: 'post'
  });
};

exports.licenseTask = licenseTask;