"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.gitCommitTask = void 0;

var _toolLib = require("@kettil/tool-lib");

var _actionConfigs = require("../../../configs/actionConfigs");

var _add = require("../../actions/git/add");

var _ls = require("../../actions/git/ls");

var _staged = require("../../actions/git/staged");

var _existFiles = require("../../cmd/existFiles");

var _analyseTask = require("../analyseTask");

var _depsTask = require("../depsTask");

var _licenseTask = require("../licenseTask");

var _testTask = require("../testTask");

const testEslint = new RegExp(`(${_actionConfigs.eslintExtensions.replace(/,/gu, '|')})$`, 'u');
const testPrettier = new RegExp(`(${_actionConfigs.prettierExtensions.replace(/,/gu, '|')})$`, 'u');

const gitCommitTask = async argv => {
  const stagedFiles = await (0, _staged.gitStagedAction)(argv, {});

  if (stagedFiles.length === 0) {
    return;
  }

  const files = await (0, _existFiles.existFiles)(stagedFiles, argv.cwd);
  const eslintFiles = files.filter(file => testEslint.test(file));
  const prettierFiles = files.filter(file => testPrettier.test(file));
  const mergedFiles = (0, _toolLib.uniqueArray)([...prettierFiles, ...eslintFiles]);
  const unstagedFiles = await (0, _ls.gitLsAction)(argv, {
    mode: 'all'
  });
  const intersectFiles = mergedFiles.filter(file => unstagedFiles.includes(file));

  if (intersectFiles.length > 0) {
    const changedFiles = intersectFiles.map(file => `       ▸ ${file}\n`).join('');
    throw new Error(`The following files were changed after adding:\n${changedFiles}`);
  }

  await (0, _analyseTask.analyseTask)({ ...argv,
    ci: false
  }, {
    eslintFiles,
    prettierFiles
  });
  await (0, _add.gitAddAction)(argv, {
    files
  });
  await (0, _testTask.testTask)({ ...argv,
    ci: true
  }, {});
  await (0, _licenseTask.licenseTask)(argv, {});
  await (0, _depsTask.depsTask)(argv, {});
};

exports.gitCommitTask = gitCommitTask;